@@ -3,7 +3,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.001006'; # VERSION
+our $VERSION = '0.001007'; # VERSION
 
 use Moose;
 with qw(
@@ -40,7 +40,6 @@ sub configure {
 			'repository.github' => 'user:xenoterracide',
 		}, ], qw(
 		AutoPrereqs
-		ReadmeFromPod
 		OurPkgVersion
 		PodWeaver
 
@@ -66,6 +65,8 @@ sub configure {
 		CheckChangesHasContent
 		Git::Remote::Check
 		Git::Contributors
+
+		ReadmeAnyFromPod
 	));
 
 	push @plugins, (
@@ -95,7 +96,7 @@ Dist::Zilla::PluginBundle::Author::XENO - Author Bundle for Caleb Cushing
 
 =head1 VERSION
 
-version 0.001006
+version 0.001007
 
 =head1 SYNOPSIS
 
